.. currentmodule:: disnake_compass.impl

Guild Parser Implementation
===========================

.. automodule:: disnake_compass.impl.parser.guild


Classes
-------

.. attributetable:: disnake_compass.impl.parser.guild.GuildParser

.. autoclass:: disnake_compass.impl.parser.guild.GuildParser
    :members:

.. attributetable:: disnake_compass.impl.parser.guild.InviteParser

.. autoclass:: disnake_compass.impl.parser.guild.InviteParser
    :members:

.. attributetable:: disnake_compass.impl.parser.guild.RoleParser

.. autoclass:: disnake_compass.impl.parser.guild.RoleParser
    :members:
